ComplexCCA
==========

.. currentmodule:: xeofs.cross

.. autoclass:: ComplexCCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexCCA.__init__
      ~ComplexCCA.components
      ~ComplexCCA.components_amplitude
      ~ComplexCCA.components_phase
      ~ComplexCCA.compute
      ~ComplexCCA.correlation_coefficients_X
      ~ComplexCCA.correlation_coefficients_Y
      ~ComplexCCA.cross_correlation_coefficients
      ~ComplexCCA.deserialize
      ~ComplexCCA.fit
      ~ComplexCCA.fraction_variance_X_explained_by_X
      ~ComplexCCA.fraction_variance_Y_explained_by_X
      ~ComplexCCA.fraction_variance_Y_explained_by_Y
      ~ComplexCCA.get_params
      ~ComplexCCA.get_serialization_attrs
      ~ComplexCCA.heterogeneous_patterns
      ~ComplexCCA.homogeneous_patterns
      ~ComplexCCA.inverse_transform
      ~ComplexCCA.load
      ~ComplexCCA.predict
      ~ComplexCCA.save
      ~ComplexCCA.scores
      ~ComplexCCA.scores_amplitude
      ~ComplexCCA.scores_phase
      ~ComplexCCA.serialize
      ~ComplexCCA.squared_covariance_fraction
      ~ComplexCCA.transform
   
   

   
   
   